@@ -1,7 +1,7 @@
 import * as React from 'react';
 
+import { t } from '@grafana/i18n';
 import { Icon, ModalsController } from '@grafana/ui';
-import { t } from 'app/core/internationalization';
 
 import { OnRowOptionsUpdate } from './RowOptionsForm';
 import { RowOptionsModal } from './RowOptionsModal';
